<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Coz00900TabelaPrecosPAController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $crudService;
    protected $entityManager;
    protected $connection;
    protected $Coz01000ConsumoPlanejado;

    public function __construct($crudService, $parameterBag, $entityManager, $connection, $Coz01000ConsumoPlanejado) {
        $this->entityManager            = $entityManager;
        $this->connection               = $connection;
        $this->Coz01000ConsumoPlanejado = $Coz01000ConsumoPlanejado;
        parent::__construct($crudService, $parameterBag);
    }
    
    private function getFiliServ($row) {
        $dataSourceName = 'servico_por_multi_filial';
    	$conditions = array(
                	    array(
                	    	"columnName" => "NRORG",
                			"operator"   => "=",
                			"value"      => $row['NRORG']
                    	    ),
                    	array(
                	    	"columnName" => "CDFILIAL",
                			"operator"   => "=",
                			"value"      => 'T'
                    	    ),
                	);
		$dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);
        $result = $dataSet->getRows();
        return $result;
    }
    
    public function procedureCalcCusto(DTO\Request\Row $request, DTO\Response $response) {
       try{
            $row = $request->getRow();
            $connection = $this->entityManager->getConnection();
            
            $servicos = $this->getFiliServ($row);
            $listaFiliServ = $this->Coz01000ConsumoPlanejado->gerarLista($servicos, $row['NRORG']); //0000127090

            $cdoperador = $this->crudService->getEnvironment()->getCdOperador(); 

            $procedureCalc = new StoredProcedure($connection, 'CALC_CUSTO_PRODUTO_ACABADO');
            
            $procedureCalc->addParam(new Param('P_CDFILCENT',    Param::PARAM_INPUT, $row['CDCENTRALCALC'],  Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new Param('P_LISTAFILSERV', Param::PARAM_INPUT, $listaFiliServ,         Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new Param('P_DTINICARD',    Param::PARAM_INPUT, $row['DTINICIAL'],      Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new Param('P_DTFINCARD',    Param::PARAM_INPUT, $row['DTFINAL'],        Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new Param('P_DTVIGENCIA',   Param::PARAM_INPUT, $row['DTVIGENCIACALC'], Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new Param('P_TIPOCUSTO',    Param::PARAM_INPUT, $row['CDTIPOCUSTO'],    Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new Param('P_CDOPERADOR',   Param::PARAM_INPUT, $cdoperador,            Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new Param('P_NRORG',        Param::PARAM_INPUT, $row['NRORG'],          Param::PARAM_TYPE_STR));
            $procedureCalc->execute();
            
            $resultQry = $this->verificaRetorno($row, $listaFiliServ);
            $response->addDataSet(new DataSet("result", $resultQry));
        }catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function verificaRetorno($row, $listaFiliServ) {
        $query = "SELECT C.CDFILIAL, C.NRCARDAPIO, C.CDSERVFILI, C.CDOPERADOR, C.DTCARDAPIO FROM CARDADIA   C INNER JOIN ( SELECT SUBSTR(CDLISTA, 1, 4) AS CDFILIAL, SUBSTR(CDLISTA, 5, 5) AS CDSERVFILI FROM LISTA WHERE NRLISTA = :P_LISTAFILSERV ) L ON C.CDFILIAL = L.CDFILIAL AND C.CDSERVFILI = L.CDSERVFILI INNER JOIN COMPCARD   P ON C.CDFILIAL = P.CDFILIAL AND P.NRCARDAPIO = C.NRCARDAPIO AND C.DTCARDAPIO BETWEEN :P_DTINICARD AND :P_DTFINCARD";
        
        $params = array(
	      'P_LISTAFILSERV' => $listaFiliServ,
	      'P_DTINICARD'    => $row['DTINICIAL'],
	      'P_DTFINCARD'    => $row['DTFINAL']
	    );
	    
	    $stmt = $this->connection->prepare($query);
		$stmt->execute($params);
    	$result = $stmt->fetchAll();
    	return $result;
    }
    
    public function tipoCusto(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $query = "SELECT CDTIPOCUSTO, NMTIPOCUSTO FROM TIPOCUSTO WHERE CDTIPOCUSTO = :CDTIPOCUSTO";
        
        $params = array(
	      'CDTIPOCUSTO' => $row[0]
	    );
	    
	    $stmt = $this->connection->prepare($query);
		$stmt->execute($params);
    	$result = $stmt->fetchAll();
    	$response->addDataSet(new DataSet("result", $result));
    }
}